pub fn has_block_collision(world: &impl CollisionWorld, aabb: WorldAabb) -> boolExpand description
Returns whether an entity box intersects any block collision shape.
pub fn has_block_collision(world: &impl CollisionWorld, aabb: WorldAabb) -> boolReturns whether an entity box intersects any block collision shape.