pub fn has_collision(world: &impl CollisionWorld, aabb: WorldAabb) -> boolExpand description
Returns whether an entity box intersects any entity or block collision shape.
pub fn has_collision(world: &impl CollisionWorld, aabb: WorldAabb) -> boolReturns whether an entity box intersects any entity or block collision shape.